@@ -15,31 +15,15 @@ describe "pcmk_common functions" do
     FileUtils.cp orig_cib, "cib-bundle.xml.orig"
   end
 
-  it "pcmk_graph_contain_id? raises proper exception" do
-    expect { pcmk_graph_contain_id?('foo', 'bar') }.to raise_error(Errno::ENOENT)
-  end
-
   it "pcs_offline noop update" do
     expect(pcs_offline('resource update ip-172.16.11.97 cidr_netmask=32', 'cib-noop.xml')).to eq ""
     expect(pcs_offline('resource update stonith-fence_ipmilan-stonith-fence-1 passwd=renVamyep3!', 'cib-noop.xml')).to eq ""
   end
-  it "pcmk_restart_resource? noop" do
-    expect(pcmk_restart_resource?('foo', "cib-noop.xml")).to eq false
-    expect(pcmk_restart_resource?('ip-172.16.11.97', "cib-noop.xml")).to eq false
-    expect(pcmk_restart_resource?('stonith-fence_ipmilan-stonith-fence-1', "cib-noop.xml")).to eq false
-  end
+
   it "pcs_offline update to resource definition" do
     expect(pcs_offline('resource update ip-172.16.11.97 cidr_netmask=31', 'cib-resource.xml')).to eq ""
     expect(pcs_offline('resource update stonith-fence_ipmilan-stonith-fence-1 passwd=NewPassword', 'cib-resource.xml')).to eq ""
   end
-  it "pcmk_restart_resource? vip resource" do
-    expect(pcmk_restart_resource?('foo', "cib-resource.xml")).to eq false
-    expect(pcmk_restart_resource?('ip-172.16.11.97', "cib-resource.xml")).to eq true
-  end
-  it "pcmk_restart_resource? stonith resource" do
-    expect(pcmk_restart_resource?('foo', "cib-resource.xml")).to eq false
-    expect(pcmk_restart_resource?('stonith-fence_ipmilan-stonith-fence-1', "cib-resource.xml")).to eq true
-  end
 
   it "pcs_offline update to bundle definition" do
     # We effectively change the number of replicas from 3 to 2
@@ -61,28 +45,21 @@ describe "pcmk_common functions" do
     expect(pcs_offline(cmd, 'cib-bundle.xml')).to eq ""
   end
 
-  it "pcmk_restart_resource? bundle resource" do
-    expect(pcmk_restart_resource?('foo', "cib-bundle.xml", true)).to eq false
-    expect(pcmk_restart_resource?('test_bundle', "cib-bundle.xml", true)).to eq true
+  it "pcmk_restart_resource_ng? noop" do
+    expect(pcmk_restart_resource_ng?('foo', "cib-noop.xml")).to eq false
+    expect(pcmk_restart_resource_ng?('ip-172.16.11.97', "cib-noop.xml")).to eq false
+    expect(pcmk_restart_resource_ng?('stonith-fence_ipmilan-stonith-fence-1', "cib-noop.xml")).to eq false
   end
-
-  context 'when crm_diff is not buggy', if: is_crm_diff_buggy?() == false do
-    it "pcmk_restart_resource_ng? noop" do
-      expect(pcmk_restart_resource_ng?('foo', "cib-noop.xml")).to eq false
-      expect(pcmk_restart_resource_ng?('ip-172.16.11.97', "cib-noop.xml")).to eq false
-      expect(pcmk_restart_resource_ng?('stonith-fence_ipmilan-stonith-fence-1', "cib-noop.xml")).to eq false
-    end
-    it "pcmk_restart_resource_ng? vip resource" do
-      expect(pcmk_restart_resource_ng?('foo', "cib-resource.xml")).to eq false
-      expect(pcmk_restart_resource_ng?('ip-172.16.11.97', "cib-resource.xml")).to eq true
-    end
-    it "pcmk_restart_resource_ng? stonith resource" do
-      expect(pcmk_restart_resource_ng?('foo', "cib-resource.xml")).to eq false
-      expect(pcmk_restart_resource_ng?('stonith-fence_ipmilan-stonith-fence-1', "cib-resource.xml")).to eq true
-    end
-    it "pcmk_restart_resource_ng? bundle resource" do
-      expect(pcmk_restart_resource_ng?('foo', "cib-bundle.xml")).to eq false
-      expect(pcmk_restart_resource_ng?('test_bundle', "cib-bundle.xml")).to eq true
-    end
+  it "pcmk_restart_resource_ng? vip resource" do
+    expect(pcmk_restart_resource_ng?('foo', "cib-resource.xml")).to eq false
+    expect(pcmk_restart_resource_ng?('ip-172.16.11.97', "cib-resource.xml")).to eq true
+  end
+  it "pcmk_restart_resource_ng? stonith resource" do
+    expect(pcmk_restart_resource_ng?('foo', "cib-resource.xml")).to eq false
+    expect(pcmk_restart_resource_ng?('stonith-fence_ipmilan-stonith-fence-1', "cib-resource.xml")).to eq true
+  end
+  it "pcmk_restart_resource_ng? bundle resource" do
+    expect(pcmk_restart_resource_ng?('foo', "cib-bundle.xml")).to eq false
+    expect(pcmk_restart_resource_ng?('test_bundle', "cib-bundle.xml")).to eq true
   end
 end
